@@ -29,7 +29,9 @@ typedef enum
 	XARCHIVETYPE_7ZIP = XARCHIVETYPE_FIRST,
 	XARCHIVETYPE_AR,
 	XARCHIVETYPE_ARJ,
+	XARCHIVETYPE_BZIP,
 	XARCHIVETYPE_BZIP2,
+	XARCHIVETYPE_BZIP3,
 	XARCHIVETYPE_CAB,
 	XARCHIVETYPE_COMPRESS,
 	XARCHIVETYPE_CPIO,
@@ -45,7 +47,9 @@ typedef enum
 	XARCHIVETYPE_RPM,
 	XARCHIVETYPE_SQUASHFS,
 	XARCHIVETYPE_TAR,
+	XARCHIVETYPE_TAR_BZIP,
 	XARCHIVETYPE_TAR_BZIP2,
+	XARCHIVETYPE_TAR_BZIP3,
 	XARCHIVETYPE_TAR_COMPRESS,
 	XARCHIVETYPE_TAR_GZIP,
 	XARCHIVETYPE_TAR_LRZIP,
@@ -191,7 +195,7 @@ struct _XArchive
 	gboolean can_freshen[2];     // can limit activity to only changed files
 	gboolean can_move;           // can delete files after adding
 	gboolean can_solid;          // can create a solid archive
-	gboolean can_recurse;        // can automatically recursion through subdirectories
+	gboolean can_recurse;        // can automatically recurse through subdirectories
 	gboolean can_compress;       // can compress at different levels
 	/* instructions */
 	gboolean do_full_path;   // extract_func, (xa_execute_add_commands)
