@@ -43,6 +43,8 @@
 #include "tar.h"
 #include "window.h"
 
+#define bzip     (archive->type == XARCHIVETYPE_BZIP)
+#define bzip3    (archive->type == XARCHIVETYPE_BZIP3)
 #define compress (archive->type == XARCHIVETYPE_COMPRESS)
 #define lrzip    (archive->type == XARCHIVETYPE_LRZIP)
 #define lz4      (archive->type == XARCHIVETYPE_LZ4)
@@ -67,6 +69,40 @@ void xa_gzip_et_al_check_lrzip (const gchar *path)
 	g_free(output);
 }
 
+static gboolean xa_gzip_et_al_zstd_option (const gchar *output, const gchar *option)
+{
+	const gchar *nl, *delim;
+	size_t op;
+
+	if (!output)
+		return FALSE;
+
+	nl = output;
+	op = strlen(option);
+
+	while ((nl = strchr(nl, '\n')))
+	{
+		nl++;
+
+		/* skip multiple leading spaces added since v1.5.4 */
+		while (*nl && (*nl == ' '))
+			nl++;
+
+		if (!*nl)
+			break;
+
+		if (strncmp(nl, option, op) == 0)
+		{
+			delim = nl + op;
+
+			if (*delim && (*delim == ' ' || (*delim == ',' && *++delim == ' ')))
+				return TRUE;
+		}
+	}
+
+	return FALSE;
+}
+
 gchar *xa_gzip_et_al_check_zstd (const gchar *compressor, const gchar *decompressor, gboolean *is_compressor)
 {
 	gchar *path, *command, *output = NULL;
@@ -82,18 +118,18 @@ gchar *xa_gzip_et_al_check_zstd (const gchar *compressor, const gchar *decompres
 	if (!path)
 		return NULL;
 
-	command = g_strconcat(path, " -h", NULL);
+	command = g_strconcat(path, " -H", NULL);
 	g_spawn_command_line_sync(command, &output, NULL, NULL, NULL);
 	g_free(command);
 
 	/* check whether decompression is available */
-	if (output && strstr(output, "\n -d "))
+	if (xa_gzip_et_al_zstd_option(output, "-d"))
 	{
 		if (found_compressor)
-			*is_compressor = (strstr(output, "\n -# ") != NULL);
+			*is_compressor = xa_gzip_et_al_zstd_option(output, "-#");
 
-		zstd_can_list = (strstr(output, "\n -l ") || strstr(output, "\n--list "));
-		zstd_can_test = (strstr(output, "\n -t ") || strstr(output, "\n--test "));
+		zstd_can_list = xa_gzip_et_al_zstd_option(output, "-l");
+		zstd_can_test = (xa_gzip_et_al_zstd_option(output, "--test") || /* check short test option just in case */ xa_gzip_et_al_zstd_option(output, "-t"));
 	}
 	else   // useless
 	{
@@ -132,7 +168,9 @@ gchar *xa_gzip_et_al_get_command (const gchar *program, gchar *workfile, gchar *
 
 static compressor_t xa_gzip_et_al_compressor (XArchive *archive)
 {
+	compressor_t bzip_compressor = {FALSE, 1, 9, 9, 1};
 	compressor_t bzip2_compressor = {FALSE, 1, 9, 9, 1};
+	compressor_t bzip3_compressor = {FALSE, 1, 16, 511, 1};
 	compressor_t compress_compressor = {FALSE, 9, 16, 16, 1};
 	compressor_t gzip_compressor = {FALSE, 1, 6, 9, 1};
 	compressor_t lrzip_compressor = {TRUE, 1, 7, 9, 1};
@@ -145,9 +183,15 @@ static compressor_t xa_gzip_et_al_compressor (XArchive *archive)
 
 	switch (archive->type)
 	{
+		case XARCHIVETYPE_BZIP:
+			return bzip_compressor;
+
 		case XARCHIVETYPE_BZIP2:
 			return bzip2_compressor;
 
+		case XARCHIVETYPE_BZIP3:
+			return bzip3_compressor;
+
 		case XARCHIVETYPE_COMPRESS:
 			return compress_compressor;
 
@@ -180,7 +224,7 @@ static compressor_t xa_gzip_et_al_compressor (XArchive *archive)
 
 static void xa_gzip_et_al_can (XArchive *archive, gboolean can)
 {
-	archive->can_test = (can && !compress && (!zstd || zstd_can_test));
+	archive->can_test = (can && !bzip && !compress && (!zstd || zstd_can_test));
 	archive->can_extract = can;
 	archive->can_password = (can && lrzip && lrzip_can_password);
 	archive->can_overwrite = can;
@@ -824,7 +868,9 @@ void xa_gzip_et_al_list (XArchive *archive)
 
 			break;
 
+		case XARCHIVETYPE_BZIP:
 		case XARCHIVETYPE_BZIP2:
+		case XARCHIVETYPE_BZIP3:
 		case XARCHIVETYPE_COMPRESS:
 		case XARCHIVETYPE_LZ4:
 		case XARCHIVETYPE_LZMA:
@@ -961,9 +1007,9 @@ void xa_gzip_et_al_add (XArchive *archive, GSList *file_list)
 	if (lrzip)
 		out = g_strconcat(" -fo ", archive_path, " --", files_str, NULL);
 	else
-		out = g_strconcat(" -c --", files_str, " > ", archive_path, NULL);
+		out = g_strconcat(" -c", bzip ? "" : " --", files_str, " > ", archive_path, NULL);
 
-	command = g_strconcat("sh -c \"exec ", archiver[archive->type].program[0], " -", compress ? "b " : (lrzip ? (*compression == '0' ? "n" : "L ") : ""), lrzip && (*compression == '0') ? "" : compression, password_str, out, "\"", NULL);
+	command = g_strconcat("sh -c \"exec ", archiver[archive->type].program[0], " -", compress || bzip3 ? "b " : (lrzip ? (*compression == '0' ? "n" : "L ") : ""), lrzip && (*compression == '0') ? "" : compression, password_str, out, "\"", NULL);
 	success = xa_run_command(archive, command);
 
 	g_free(command);
