@@ -79,6 +79,7 @@ static void xa_prefs_dialog_set_default_options (Prefs_dialog_data *prefs_data)
 	gtk_combo_box_set_active (GTK_COMBO_BOX(prefs_data->combo_prefered_format),0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_data->prefer_unzip), TRUE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs_data->confirm_deletion),TRUE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_data->advanced_isearch), TRUE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs_data->store_output),FALSE);
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX(prefs_data->combo_icon_size),0);
@@ -215,6 +216,7 @@ Prefs_dialog_data *xa_create_prefs_dialog()
 	prefs_data->prefer_unzip = gtk_check_button_new_with_mnemonic(_("Prefer unzip for zip files (requires restart)"));
 	gtk_box_pack_start(GTK_BOX(vbox4), prefs_data->prefer_unzip, FALSE, FALSE, 0);
 	gtk_button_set_focus_on_click(GTK_BUTTON(prefs_data->prefer_unzip), FALSE);
+	gtk_widget_set_tooltip_text(prefs_data->prefer_unzip, _("Even if other, perhaps more powerful programs are installed to handle zip archives, the traditional \"unzip\" and \"zip\" will still be used"));
 
 	prefs_data->confirm_deletion = gtk_check_button_new_with_mnemonic (_("Confirm deletion of files"));
 	gtk_box_pack_start (GTK_BOX (vbox4), prefs_data->confirm_deletion, FALSE, FALSE, 0);
@@ -225,10 +227,15 @@ Prefs_dialog_data *xa_create_prefs_dialog()
 	gtk_button_set_focus_on_click (GTK_BUTTON (prefs_data->check_sort_filename_column), FALSE);
 	gtk_widget_set_tooltip_text(prefs_data->check_sort_filename_column, _("The filename column is sorted after loading the archive"));
 
+	prefs_data->advanced_isearch = gtk_check_button_new_with_mnemonic(_("Advanced incremental search (requires restart)"));
+	gtk_box_pack_start(GTK_BOX(vbox4), prefs_data->advanced_isearch, FALSE, FALSE, 0);
+	gtk_button_set_focus_on_click(GTK_BUTTON(prefs_data->advanced_isearch), FALSE);
+	gtk_widget_set_tooltip_text(prefs_data->advanced_isearch, _("The incremental search is also performed within filenames rather than just at the beginning of them"));
+
 	prefs_data->store_output = gtk_check_button_new_with_mnemonic (_("Store archiver output"));
 	gtk_box_pack_start (GTK_BOX (vbox4), prefs_data->store_output, FALSE, FALSE, 0);
 	gtk_button_set_focus_on_click (GTK_BUTTON (prefs_data->store_output), FALSE);
-	gtk_widget_set_tooltip_text(prefs_data->store_output, _("This option consumes more memory with large archives"));
+	gtk_widget_set_tooltip_text(prefs_data->store_output, _("Command line output is captured and can be reviewed, but this consumes additional memory"));
 
 	label1 = gtk_label_new ("");
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (prefs_data->prefs_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (prefs_data->prefs_notebook), 0), label1);
@@ -417,6 +424,7 @@ void xa_prefs_save_options(Prefs_dialog_data *prefs_data, const char *filename)
 	g_key_file_set_boolean(xa_key_file, PACKAGE, "prefer_unzip", gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_data->prefer_unzip)));
 	g_key_file_set_boolean (xa_key_file,PACKAGE,"confirm_deletion",gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (prefs_data->confirm_deletion)));
 	g_key_file_set_boolean (xa_key_file,PACKAGE,"sort_filename_content",gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (prefs_data->check_sort_filename_column)));
+	g_key_file_set_boolean(xa_key_file, PACKAGE, "advanced_isearch", gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_data->advanced_isearch)));
 	g_key_file_set_boolean (xa_key_file,PACKAGE,"store_output",gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (prefs_data->store_output)));
 
 	g_key_file_set_integer(xa_key_file, PACKAGE, "icon_size", gtk_combo_box_get_active(GTK_COMBO_BOX(prefs_data->combo_icon_size)) + 2);
@@ -531,7 +539,7 @@ void xa_prefs_load_options(Prefs_dialog_data *prefs_data)
 	gchar *xarchiver_config_dir, *old_dir, *old_config;
 	GKeyFile *xa_key_file = g_key_file_new();
 	GError *error = NULL;
-	gboolean unzip, toolbar;
+	gboolean unzip, aisearch, toolbar;
 	gint idx, val;
 
 	config_dir = g_get_user_config_dir();
@@ -596,6 +604,19 @@ void xa_prefs_load_options(Prefs_dialog_data *prefs_data)
 		gtk_combo_box_set_active(GTK_COMBO_BOX(prefs_data->combo_icon_size), idx);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(prefs_data->check_show_comment),g_key_file_get_boolean(xa_key_file,PACKAGE,"show_archive_comment",NULL));
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(prefs_data->check_sort_filename_column),g_key_file_get_boolean(xa_key_file,PACKAGE,"sort_filename_content",NULL));
+		aisearch = g_key_file_get_boolean(xa_key_file, PACKAGE, "advanced_isearch", &error);
+
+		if (error)
+		{
+			if (error->code == G_KEY_FILE_ERROR_KEY_NOT_FOUND)
+				/* preserve default setting with existing, old config file */
+				aisearch = TRUE;
+
+			g_error_free(error);
+			error = NULL;
+		}
+
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_data->advanced_isearch), aisearch);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(prefs_data->show_sidebar),g_key_file_get_boolean(xa_key_file,PACKAGE,"show_sidebar",NULL));
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(prefs_data->show_location_bar),g_key_file_get_boolean(xa_key_file,PACKAGE,"show_location_bar",NULL));
 		toolbar = g_key_file_get_boolean(xa_key_file,PACKAGE,"show_toolbar",&error);
