@@ -62,9 +62,15 @@ static XArchiveType xa_tar_get_compressor_type (XArchive *archive)
 {
 	switch (archive->type)
 	{
+		case XARCHIVETYPE_TAR_BZIP:
+			return XARCHIVETYPE_BZIP;
+
 		case XARCHIVETYPE_TAR_BZIP2:
 			return XARCHIVETYPE_BZIP2;
 
+		case XARCHIVETYPE_TAR_BZIP3:
+			return XARCHIVETYPE_BZIP3;
+
 		case XARCHIVETYPE_TAR_COMPRESS:
 			return XARCHIVETYPE_COMPRESS;
 
